@@ -9,10 +9,11 @@ from dynamodb.dynamodb import DynamoDB
 
 class AbstractAutomation(abc.ABC):
 
-    def __init__(self, url: str, table: str):
+    def __init__(self, url: str, table: str, profile: str):
         self.url = url
         self.driver = self.__get_driver()
         self.db = DynamoDB(table=table)
+        self.profile = profile
 
     def __get_driver(self) -> webdriver.Chrome:
         options = webdriver.ChromeOptions()
@@ -24,6 +25,7 @@ class AbstractAutomation(abc.ABC):
         options.add_argument("--window-size=1280x1696")
         options.add_argument("--single-process")
         options.add_argument("--disable-dev-shm-usage")
+        options.add_argument("--disable-dev-tools")
         options.add_argument("--no-zygote")
         options.add_argument(f"--user-data-dir={mkdtemp()}")
         options.add_argument(f"--data-path={mkdtemp()}")
